@echo off
:====================================================================
: FIDOFTP.BAT  (c) copyright 1997 Santronics Software Inc
:
: NOTE: This batch file is designed for PX/WINS sysops.
:
: This batch file will handle complete FTPHUB operations.  It does
: complete FTN netmail, echos and TICS and Internet Email and Newsgroups.
: In addition, it will do PXFIDS, which offers a way to send FTN data
: (netmail, echos and tics) to downlinks and uplinks.
:
: This batch file does the following:
:
: EXPORT:  Move files to be sent to the EXPORT directory.
:
: 1) If wcgate is defined, move all wcmail gateway move to export
:    directory.
:
: 2) Run PXNET to create *.PKT files for routed netmail to FTP HUB.
:    The *.PKT files are created in the export directory.
:
: 3) Move all echo bundles belonging to the FTP HUB to the export
:    directory.
:
: 4) if available, runs PXFIDS /EXPORT to scan PX data queues to
:    create internet email messages to route to down links using
:    PXFIDS.
:
: DIAL: Dial FTP HUB, send/receive all files.
:
: 1) Use the new iFTP.EXE intelligent FTP script system to reliably
:    sent and receive all files.
:
: IMPORT:  Move all new files into appropiate directories.
:
: 1) Make PXNET and ECHO QUEUE files as sent
:
: 2) Run PXFIDS to process any incoming FIDS Internet Email. PXFIDS
:    will process what it needs, and leave the rest behind.
:
: 3) Unzip and move all remaining Internet email and newsgroup to
:    the WCMAIL gateway directory.
:
: 4) Move all echo mail files to the inbound\echo directory.
:
: 5) Move all tic files to the inbound\tics directory.
:
: 6) Move all remaining files to the inbound directory.
:
: 7) Create semaphores to trigger PX/WINS PXECHO
:
:====================================================================
:                      VARIABLES TO BE DEFINED
:====================================================================

: bname         bundle name for your ftp hub. See BUNDNAME.EXE on CD
: fido          fido address of ftp hub
: export        local export directory, make a directory call export
: import        local import directory, make a directory call import
: wcgate        WC5 Gateway Host directory, ie. c:\wc5\gateway\paonline

 set bname=
 set fido=1:270/101
 set export=export
 set import=import
 set wcgate=c:\wc5\gateway\paonline

:====================================================================
:                       START BATCH OPERATION
:====================================================================

:--------------------------------------------------------------------
: check to make sure bname is defined
:--------------------------------------------------------------------

  if .%bname% == .. goto bnameerr

:--------------------------------------------------------------------
: If using wcmail, then move outbound mail to export directory
:--------------------------------------------------------------------

  if .%wcgate%. == .. goto nowcout
  if not exist %wcgate%\*.cmd move %wcgate%\*.cmd export
  if not exist %wcgate%\*.xqt move %wcgate%\*.xqt export
  if not exist %wcgate%\*.dat move %wcgate%\*.dat export
:nowcout

:--------------------------------------------------------------------
: check for PX exported fido mail, if any, move to the export
: directory
:--------------------------------------------------------------------

  pxnet /SCAN /PACK %fido% /FILE %export%\%bname%.pkt
  if exist outbound\%bname%.* move outbound\%bname%.* %export%

:--------------------------------------------------------------------
: Is using FIDS, then check for any fids mail
:--------------------------------------------------------------------

  if exist pxfids.exe pxfids /EXPORT

:--------------------------------------------------------------------
: Dial your provider and run iFTP script
:--------------------------------------------------------------------

  iftp /dial /run ftphub
  if errorlevel 1 goto raserror

:--------------------------------------------------------------------
: Mark PX queues as sent
:--------------------------------------------------------------------

  pxnet /sent %fido%
  viewout /sent %fido%

:--------------------------------------------------------------------
: If something came in so, process it
:--------------------------------------------------------------------

  if not exist %import%\*.* goto end

:--------------------------------------------------------------------
: Check for any import FIDS mail.  FIDS will process any inbound
: internet email and delete the files in the import directory,
: leaving behind the rest for others to process.
:--------------------------------------------------------------------

  if exist pxfids.exe pxfids /IMPORT

:--------------------------------------------------------------------
: if using wcgate, then check for imported internet and newsgroups
:--------------------------------------------------------------------

  if .%wcgate%. == .. goto nowcin
  if exist %import%\*.d move %import%\*.d %wcgate%
  if exist %import%\*.x move %import%\*.x %wcgate%
  if not exist %import%\*.baz pkunzip -o %import%\*.baz %wcgate%
  if not exist %import%\*.baz del %import%\*.baz
:nowcin

:--------------------------------------------------------------------
: move bundles into inbound\echo directory
:--------------------------------------------------------------------

  if exist %import%\*.MO? move %import%\*.MO? inbound\echo
  if exist %import%\*.TU? move %import%\*.TU? inbound\echo
  if exist %import%\*.WE? move %import%\*.WE? inbound\echo
  if exist %import%\*.TH? move %import%\*.TH? inbound\echo
  if exist %import%\*.FR? move %import%\*.FR? inbound\echo
  if exist %import%\*.SA? move %import%\*.SA? inbound\echo
  if exist %import%\*.SU? move %import%\*.SU? inbound\echo

:--------------------------------------------------------------------
: move tics to inbound\tics directory
:--------------------------------------------------------------------

  if exist %import%\*.TIC move %import%\*.TIC inbound\tics

:--------------------------------------------------------------------
: move remaining files to inbound directory, px expects TIC files
: to be in the normal inbound directory
:--------------------------------------------------------------------

  if exist %import%\*.*   move %import%\*.* inbound

  echo >inbound\sema\$toss.0
  echo >inbound\sema\$tics.0

  goto end

:-----------------------------------------------------------------------
:bnameerr
  echo define the bname variable. see bundname.exe

:-----------------------------------------------------------------------
:raserror

  ECHO FAILURE TO CONNECT
  goto end

:end
 set bname=
 set fido=
 set export=
 set import=
 set wcgate=

